@@ -596,7 +596,8 @@ assign.MC <- function(x, train.inds=c(0.5,0.7,0.9), train.loci=c(0.1,0.25,0.5, 1
     }#else if(length(x)==4)
     stopCluster(cl)
     #Output a metadata file
-    cat(" Analysis Description (R - assignPOP ver.",packageVersion("assignPOP"),")\n",
+    version <- as.character(packageVersion("assignPOP"))
+    cat(" Analysis Description ( R - assignPOP ver.",version,")\n",
         "Perform assign.MC() @", format(Sys.time()),"\n\n",
         "train.inds =",train.inds,"\n",
         "train.loci =",train.loci,"\n",
@@ -606,7 +607,7 @@ assign.MC <- function(x, train.inds=c(0.5,0.7,0.9), train.loci=c(0.1,0.25,0.5, 1
         "Data scaled and centerd:",scaled,"\n",
         "PC retaining criteria:",pca.PCs,"\n",
         "PCA for non-genetic data:",pca.method,"\n",
-        "Machine-learning model:",model,"\n\n",
+        "Machine learning model:",model,"\n\n",
         "Input Data (",datatype,")\n",
         "Number of individuals:",sum(popSizes),"\n",
         "Number of loci:",noLocus,"\n",
@@ -815,7 +816,8 @@ assign.MC <- function(x, train.inds=c(0.5,0.7,0.9), train.loci=c(0.1,0.25,0.5, 1
     }#foreach
     stopCluster(cl)
     #Output a metadata file
-    cat(" Analysis Description (R - assignPOP ver.",packageVersion("assignPOP"),")\n",
+    version <- as.character(packageVersion("assignPOP"))
+    cat(" Analysis Description ( R - assignPOP ver.",version,")\n",
         "Perform assign.MC() @", format(Sys.time()),"\n\n",
         "train.inds =",train.inds,"\n",
         "iterations =",iterations,"\n",
@@ -823,7 +825,7 @@ assign.MC <- function(x, train.inds=c(0.5,0.7,0.9), train.loci=c(0.1,0.25,0.5, 1
         "Data scaled and centerd:",scaled,"\n",
         "PCA for dimensionality reduction:",pca.method,"\n",
         "PC retaining criteria:",pca.PCs,"\n",
-        "Machine-learning model:",model,"\n\n",
+        "Machine learning model:",model,"\n\n",
         "Input Data (Non-genetics)\n",
         "Number of individuals:",sum(popSizes),"\n",
         "Number of non-genetic variables:",noVars,"\n",
