@@ -290,12 +290,13 @@ assign.X <- function(x1, x2, dir=NULL, scaled=F, pca.method="mixed", pca.PCs="ka
     res_popSizes <- table(outcome_matrix$pred.pop)
     
     #Output a metadata file
-    cat(" Analysis Description (R - assignPOP ver.",packageVersion("assignPOP"),")\n",
+    version <- as.character(packageVersion("assignPOP"))
+    cat(" Analysis Description ( R - assignPOP ver.",version,")\n",
         "Perform assign.X() @", format(Sys.time()),"\n\n",
         "Data scaled and centerd:",scaled,"\n",
         "PC retaining criteria:",pca.PCs,"\n",
         "PCA for non-genetic data:",pca.method,"\n",
-        "Machine-learning model:",model,"\n\n",
+        "Machine learning model:",model,"\n\n",
         "Input Data (",datatype,")\n",
         "Number of known individuals:",sum(popSizes),"\n",
         "Number of known populations", noPops,"\n",
@@ -516,12 +517,13 @@ assign.X <- function(x1, x2, dir=NULL, scaled=F, pca.method="mixed", pca.PCs="ka
     #Count number of unknown inds assigned to pops
     res_popSizes <- table(outcome_matrix$pred.pop)
     #Output a metadata file
-    cat(" Analysis Description (R - assignPOP ver.",packageVersion("assignPOP"),")\n",
+    version <- as.character(packageVersion("assignPOP"))
+    cat(" Analysis Description ( R - assignPOP ver.",version,")\n",
         "Perform assign.X() @", format(Sys.time()),"\n\n",
         "Data scaled and centerd:",scaled,"\n",
         "PC retaining criteria:",pca.PCs,"\n",
         "PCA for non-genetic data:",pca.method,"\n",
-        "Machine-learning model:",model,"\n\n",
+        "Machine learning model:",model,"\n\n",
         "Input Data (",datatype,")\n",
         "Number of known individuals:",sum(popSizes),"\n",
         "Number of non-genetic variables:",length(common_VarNames),"\n",
